@@ -212,6 +212,12 @@ NetworkManager::Device::Type NetworkManager::DevicePrivate::convertType(uint typ
     case 30:
         // NM_DEVICE_TYPE_WIFI_P2P
         return NetworkManager::Device::WifiP2P;
+    case 31:
+        // NM_DEVICE_TYPE_VRF
+        return NetworkManager::Device::VRF;
+    case 32:
+        // NM_DEVICE_TYPE_LOOPBACK
+        return NetworkManager::Device::Loopback;
     }
 
     return NetworkManager::Device::UnknownType;
@@ -241,9 +247,7 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
 
     // qCDebug(NMQT) << property  << " - " << value;
     if (property == QLatin1String("ActiveConnection")) {
-        // FIXME workaround, because NM doesn't Q_EMIT correct value
-        // d->activeConnection = value.value<QDBusObjectPath>.path();
-        activeConnection = deviceIface.activeConnection().path();
+        activeConnection = value.value<QDBusObjectPath>().path();
         Q_EMIT q->activeConnectionChanged();
     } else if (property == QLatin1String("Autoconnect")) {
         autoconnect = value.toBool();
